==> xfce-4.2.3.2-src.tar.bz2: xfwm4-4.2.3.2/src/stacking.h <==
/*      $Id: stacking.h 12180 2004-12-05 23:02:28Z olivier $
 
        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2, or (at your option)
        any later version.
 
        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.
 
        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
        xfwm4    - (c) 2002-2004 Olivier Fourdan
 
 */

#ifndef INC_STACKING_H
#define INC_STACKING_H

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include <glib.h>
#include "screen.h"
#include "client.h"

void            clientApplyStackList (ScreenInfo *);
Client         *clientGetLowestTransient (Client *);
Client         *clientGetHighestTransientOrModalFor (Client *);
gboolean        clientIsTopMost (Client *);
Client         *clientGetTopMostForGroup (Client *);
Client         *clientGetNextTopMost (ScreenInfo *, int, Client *);
Client         *clientGetBottomMost (ScreenInfo *, int, Client *);
Client         *clientAtPosition (ScreenInfo *, int, int, Client *);
void            clientRaise (Client *);
void            clientLower (Client *);
gboolean        clientAdjustFullscreenLayer (Client *, gboolean);
void            clientAddToList (Client *);
void            clientRemoveFromList (Client *);
GList          *clientGetStackList (ScreenInfo *);
void            clientSetLastRaise (Client *);
Client         *clientGetLastRaise (ScreenInfo *);
void            clientClearLastRaise (ScreenInfo *);

#endif /* INC_STACKING_H */

==> xfce-4.3.90.2-src.tar.bz2: xfwm4-4.3.90.2/src/stacking.h <==
/*      $Id: stacking.h 19935 2006-02-18 08:21:05Z olivier $
 
        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2, or (at your option)
        any later version.
 
        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.
 
        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
        xfwm4    - (c) 2002-2006 Olivier Fourdan
 
 */

#ifndef INC_STACKING_H
#define INC_STACKING_H

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include <glib.h>
#include "screen.h"
#include "client.h"

void            clientApplyStackList (ScreenInfo *);
Client         *clientGetLowestTransient (Client *);
Client         *clientGetHighestTransientOrModalFor (Client *);
gboolean        clientIsTopMost (Client *);
Client         *clientGetTopMostForGroup (Client *);
Client         *clientGetNextTopMost (ScreenInfo *, int, Client *);
Client         *clientGetBottomMost (ScreenInfo *, int, Client *);
Client         *clientAtPosition (ScreenInfo *, int, int, Client *);
void            clientRaise (Client *, Window);
void            clientLower (Client *, Window);
gboolean        clientAdjustFullscreenLayer (Client *, gboolean);
void            clientAddToList (Client *);
void            clientRemoveFromList (Client *);
GList          *clientGetStackList (ScreenInfo *);
void            clientSetLastRaise (Client *);
Client         *clientGetLastRaise (ScreenInfo *);
void            clientClearLastRaise (ScreenInfo *);

#endif /* INC_STACKING_H */
